/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';
import { useState, useEffect } from '@wordpress/element';
import apiFetch from '@wordpress/api-fetch';
import {TextControl, RadioControl, PanelBody, ToggleControl } from '@wordpress/components';
import { InspectorControls } from '@wordpress/block-editor';
import { useSelect } from '@wordpress/data';



/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps, InnerBlocks } from '@wordpress/block-editor';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';
import './style.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit({
	attributes,
	setAttributes,
	isSelected,
}) {
	const [ error, setError ]       = useState( null );
    const [ metaId, setId ]       = useState( null );
    const [ mypost, setPost ]       = useState( [] );
    const [ isLoaded, setIsLoaded ] = useState( false );
	const { 
		data_type, 
		data_value, 
		custom_title, 
		custom_height, 
		display_type,
		custom_scrollbar,
		link_target,
		button_text,
		link_button_class,
		postType,
		imageCaption
	  } = attributes;
	  const postId = useSelect((select) => {
        return select('core/editor').getCurrentPostId();
      });
    useEffect( () => {
        apiFetch( { path: `alike/v1/data?options=${data_type}&posttype=${postType}`} ).then(
            ( result ) => {
                setIsLoaded( true );
                setPost( result );
            },
            ( error ) => {
                setIsLoaded( true );
                setError( error );
            }
        );
    }, [data_type, data_value, postType] );
	useEffect( () => {
        apiFetch( { path: `alike/v1/meta?id=${postId}`} ).then(
            ( result ) => {
                setIsLoaded( true );
                setAttributes( {postType: result});
            },
            ( error ) => {
                setIsLoaded( true );
                setError( error );
            }
        );
    }, [] );
	
	return (
		<>
			<InspectorControls>
				<PanelBody>
			 	{data_value == 'post_thumbnail' &&(		
				<ToggleControl
            label="Show Image Caption?"
            checked={imageCaption}
            onChange={ (e) => setAttributes( {imageCaption: e} ) }
         />
				 )}
					{ data_type == 'meta_keys' && (
						<RadioControl
							label="Display Type"
							selected={ display_type }
							options={ [
								{ label: 'Simple', value: 'simple' },
								{ label: 'Boolean', value: 'boolean' },
								{ label: 'Hiperlink', value: 'hyperlink' },
							] }
							onChange={ e => setAttributes( {display_type: e} ) }
						/>
					)}
					<RadioControl
						label= {__("Enable custom scroll bar", 'alike')}
						selected={ custom_scrollbar }
						options={ [
							{ label: 'Enable', value: 'enable' },
							{ label: 'Disable', value: 'disable' },
						] }
						onChange={ e => setAttributes( {custom_scrollbar: e} ) }
					/>
					{display_type == 'hyperlink' && (
				    <div>
						<div>
							<RadioControl
							label= {__("ENTER TARGET", 'alike')}
							selected={ link_target }
							options={ [
								{ label: 'Self', value: '_self' },
								{ label: 'Blank', value: '_blank' },
							] }
							onChange={ e => setAttributes( {link_target: e} ) }
							/>
						</div>
						<div>
						</div>
						<div>
						<TextControl
						label= {__('ENTER BUTTON TEXT TO SHOW', 'alike')}
						value={ button_text }
						onChange={ e => setAttributes( {button_text: e} ) }
						/>
						</div>
						<div>
						<TextControl
						label= {__('ENTER LINK BUTTON CLASS TO ADD', 'alike')}
						value={ link_button_class }
						onChange={ e => setAttributes( {link_button_class: e} ) }
						/>
						</div>
					</div>		
					)

					}
				</PanelBody>
			</InspectorControls>

		<div { ...useBlockProps() }>

			{isSelected && (
			<div className='edit-option'>
				<select onChange={e => setAttributes({data_type: e.target.value})} value={data_type} >
					<option value={'meta_keys'}>{__('Meta Keys', 'alike')}</option>
					<option value={'taxonomy_keys'}>{__('Taxonomy Keys', 'alike')}</option>
					<option value={'post_keys'}>{__('Post keys', 'alike')}</option>
				</select>
			   { isLoaded && (
				<select onChange={e => setAttributes({data_value: e.target.value})} value={data_value}>
					 <option>{__('Select', 'alike')}</option>
						{
						mypost.map((item, i) => {
							return (<option value={item}>{item.replace("_", " ")}</option>)
						})}
				</select>
				)}
				{
					<TextControl
					label= {__('Custom Title', 'alike')}
					value={ custom_title }
					onChange={ e => setAttributes( {custom_title: e} ) }
				   />
				
				}
				{
					<TextControl
					label={__("Custom Hight", "alike")}
					value={ custom_height }
					onChange={ e => setAttributes( {custom_height: e} ) }
				   />
				
				}
			</div>
			)}
			{!isSelected && (
				<>
				 <div className='alike-admin-tr'>
						<div className='td'>
								{custom_title ? custom_title : data_type.replaceAll('_', ' ')}
						</div>
						<div className='td'>
								{__('Content', 'alike')}
						</div>
						<div className='td'>
							{__('Content', 'alike')}
						</div>
						<div className='td'>
							{__('Content', 'alike')}
						</div>
				 </div>
				</>
			)}
		</div>
		</>
	);
}
